import { Component, h, State, Event, Prop, Watch, Fragment } from '@stencil/core';
import Sortable from 'sortablejs';
export class MyComponent {
  constructor() {
    this.previewVisible = false;
    this.isOnlyComputer = false;
    this.scaleName = '';
    this.scaleDesc = '';
    this.questionItemList = [];
    this.resultScore = 0;
    this.isPC = true;
    this.scaleInfo = null;
    this.isPreviewQuestion = false; // 是否为预览
    this.isOnlyPreview = false; // 只是预览
    this.sortArr = [];
    this.editScaleItem = {
      questionRadioList: [],
      dtoIndex: 0
    };
    this.isVisible = false;
    this.handleGetQuestionItemByType = (type, len) => {
      switch (type) {
        case "单项填空":
          return {
            "isRequired": 1,
            "orderbyId": len + 1,
            "questionName": "单项填空",
            "questionNpsList": null,
            "questionRadioList": null,
            "questionTableList": null,
            "questionType": "1",
            isShowEditOption: false,
            scaleQuestionVOList: []
          };
        case "评分单选":
          return {
            "isRequired": 1,
            "orderbyId": len + 1,
            "questionName": "评分单选",
            "questionNpsList": null,
            "questionRadioList": [
              {
                "isFilled": 0,
                "optionContent": null,
                "optionName": "选项1",
                "optionScore": "10",
                "ruleScore": 0,
                "ruleType": 1
              }, {
                "isFilled": 0,
                "optionContent": null,
                "optionName": "选项2",
                "optionScore": "10",
                "ruleScore": 0,
                "ruleType": 1
              },
              {
                "isFilled": 0,
                "optionContent": null,
                "optionName": "选项3",
                "optionScore": "10",
                "ruleScore": 0,
                "ruleType": 1
              }
            ],
            "questionTableList": null,
            "questionType": "2",
            isShowEditOption: false,
            scaleQuestionVOList: []
          };
        case "NPS量表":
          return {
            "isRequired": 1,
            "orderbyId": len + 1,
            "questionName": "NPS量表",
            "questionNpsList": [
              {
                "isScore": 0,
                "optionName": "1",
                "optionScore": 1
              }, {
                "isScore": 0,
                "optionName": "2",
                "optionScore": 2
              }, {
                "isScore": 0,
                "optionName": "3",
                "optionScore": 3
              }, {
                "isScore": 0,
                "optionName": "4",
                "optionScore": 4
              }, {
                "isScore": 0,
                "optionName": "5",
                "optionScore": 5
              }, {
                "isScore": 0,
                "optionName": "6",
                "optionScore": 6
              }, {
                "isScore": 0,
                "optionName": "7",
                "optionScore": 7
              }, {
                "isScore": 0,
                "optionName": "8",
                "optionScore": 8
              }, {
                "isScore": 0,
                "optionName": "9",
                "optionScore": 9
              }, {
                "isScore": 0,
                "optionName": "10",
                "optionScore": 10
              }
            ],
            "questionRadioList": null,
            "questionTableList": null,
            "questionType": "3",
            isShowEditOption: false,
            scaleQuestionVOList: []
          };
        case "表格填空":
          return {
            "isRequired": 1,
            "orderbyId": len + 1,
            "questionName": "表格填空",
            "questionNpsList": null,
            "questionRadioList": null,
            rowList: [
              { rowName: '行标题1' },
              { rowName: '行标题2' }
            ],
            colList: [
              { colName: '列标题1' },
              { colName: '列标题2' },
              { colName: '列标题3' }
            ],
            "questionTableList": [
              {
                "colName": "列标题1",
                "rowName": "行标题1",
                value: 1
              }, {
                "colName": "列标题2",
                "rowName": "行标题1",
                value: 2
              }, {
                "colName": "列标题3",
                "rowName": "行标题1",
                value: 3
              },
              {
                "colName": "列标题1",
                "rowName": "行标题2",
                value: 4
              }, {
                "colName": "列标题2",
                "rowName": "行标题2",
                value: 5
              }, {
                "colName": "列标题3",
                "rowName": "行标题2",
                value: 6
              }
            ],
            "questionType": "4",
            isShowEditOption: false,
            scaleQuestionVOList: []
          };
        case "问题组":
          return {
            "isRequired": 1,
            "orderbyId": len + 1,
            "questionName": "问题组",
            "questionNpsList": null,
            "questionRadioList": null,
            "questionTableList": null,
            "questionType": "6",
            isEditGroup: true,
            isShowEditOption: false,
            scaleQuestionVOList: []
          };
        case "段落说明":
          return {
            "isRequired": 1,
            "orderbyId": len + 1,
            "questionName": "段落说明",
            "questionNpsList": null,
            "questionRadioList": null,
            "questionTableList": null,
            "questionType": "5",
            isShowEditOption: false,
            scaleQuestionVOList: []
          };
        default:
          break;
      }
    };
    this.handleValue = (formName, event) => {
      const inputValue = event.target.value;
      if (formName === 'scaleName') {
        this.scaleName = inputValue;
      }
      else {
        this.scaleDesc = inputValue;
      }
    };
    this.isExistEditGroup = () => {
      const filterActiveEditGroup = this.questionItemList.filter((item) => item.isEditGroup);
      console.log(filterActiveEditGroup.length !== 0, 'isExistEditGroup');
      return filterActiveEditGroup.length !== 0;
    };
    // 左侧点击右侧新增
    this.handleLeftBarClick = (e) => {
      if (e.type !== 'item')
        return;
      // 如果不存在正在编辑的问题组，则添加在最外层
      if (!this.isExistEditGroup()) {
        this.questionItemList = [
          ...this.questionItemList,
          this.handleGetQuestionItemByType(e.label, this.questionItemList.length)
        ];
        console.log(this.questionItemList, 'questionItemList');
      }
      else {
        if (e.label === '问题组')
          return;
        this.questionItemList = this.questionItemList.map((qustionItem) => (qustionItem.isEditGroup ? Object.assign(Object.assign({}, qustionItem), { isEditGroup: true, scaleQuestionVOList: [
            ...qustionItem.scaleQuestionVOList,
            Object.assign(Object.assign({}, this.handleGetQuestionItemByType(e.label, qustionItem.scaleQuestionVOList.length)), { groupId: qustionItem.orderbyId })
          ] }) : qustionItem));
      }
      console.log(e, '--', this.questionItemList);
    };
    // 标题修改
    this.handleTitleChange = (scaleItem, event) => {
      const inputValue = event.target.value;
      console.log(scaleItem, event, inputValue);
      if (scaleItem.groupId) {
        this.questionItemList = this.questionItemList.map((item) => (item.orderbyId === scaleItem.groupId ? Object.assign(Object.assign({}, item), { scaleQuestionVOList: item.scaleQuestionVOList.map((groupItem) => (groupItem.orderbyId === scaleItem.orderbyId ? Object.assign(Object.assign({}, groupItem), { questionName: inputValue }) : groupItem)) }) : item));
      }
      else {
        this.questionItemList = this.questionItemList.map((item) => (item.orderbyId === scaleItem.orderbyId ? Object.assign(Object.assign({}, item), { questionName: inputValue }) : item));
      }
    };
    // 删除按钮
    this.handleDeleteScaleItem = (scaleItem) => {
      if (scaleItem.groupId) {
        this.questionItemList = this.questionItemList.map((qustionItem) => (qustionItem.orderbyId === scaleItem.groupId ? Object.assign(Object.assign({}, qustionItem), { scaleQuestionVOList: qustionItem.scaleQuestionVOList.filter((item) => item.orderbyId !== scaleItem.orderbyId) }) : qustionItem));
      }
      else {
        this.questionItemList = this.questionItemList.filter((item) => item.orderbyId !== scaleItem.orderbyId);
      }
    };
    this.hideAllPopover = () => {
      this.questionItemList = this.questionItemList.map((item) => {
        var _a;
        return (Object.assign(Object.assign({}, item), { scaleQuestionVOList: (_a = item === null || item === void 0 ? void 0 : item.scaleQuestionVOList) === null || _a === void 0 ? void 0 : _a.map((groupItem) => (Object.assign(Object.assign({}, groupItem), { isShowEditOption: false }))), isShowEditOption: false }));
      });
    };
    // 展示底部编辑框
    this.showEditPopover = (scaleItem) => {
      if (this.isPreviewQuestion || this.previewVisible)
        return;
      console.log(scaleItem, 'scaleItem');
      // 如果不存在正在编辑的问题组，则添加在最外层
      // 编辑group状态下
      if (scaleItem.groupId) {
        this.questionItemList = this.questionItemList.map((item) => {
          var _a;
          return (item.orderbyId === scaleItem.groupId ? Object.assign(Object.assign({}, item), { scaleQuestionVOList: (_a = item === null || item === void 0 ? void 0 : item.scaleQuestionVOList) === null || _a === void 0 ? void 0 : _a.map((groupItem) => (Object.assign(Object.assign({}, groupItem), { isShowEditOption: scaleItem.orderbyId === groupItem.orderbyId ? !groupItem.isShowEditOption : false }))) }) : Object.assign(Object.assign({}, item), { isShowEditOption: false }));
        });
      }
      else {
        // 选中的id
        this.questionItemList = this.questionItemList.map((item) => {
          var _a;
          return (Object.assign(Object.assign({}, item), { isShowEditOption: scaleItem.orderbyId === item.orderbyId ? !item.isShowEditOption : false, scaleQuestionVOList: (_a = item.scaleQuestionVOList) === null || _a === void 0 ? void 0 : _a.map((groupItem) => (Object.assign(Object.assign({}, groupItem), { isShowEditOption: false }))) }));
        });
      }
      console.log(this.questionItemList, 'questionItemList');
    };
    this.getScaleIndexByFilterParagh = (curIndex) => {
      const paraghList = this.questionItemList.slice(0, curIndex).filter((item) => item.questionType == 5);
      return paraghList.length;
    };
    // 评分单选
    this.singleInput = (scaleItem, scaleItemIndex) => {
      var _a;
      const paraghLength = this.getScaleIndexByFilterParagh(scaleItemIndex);
      console.log(paraghLength, 'paraghLength');
      return (h("div", { class: "right-preview-item", "data-id": scaleItem.orderbyId, key: scaleItem.orderbyId },
        h("div", { style: { position: 'relative' } },
          h("div", { class: "item-preview" },
            scaleItem.isRequired == 1 && h("span", { class: "req" }, "*"),
            h("span", null, `${scaleItemIndex + 1 - paraghLength}.${scaleItem.questionName}`)),
          h("div", { class: "item-preview-mask", onClick: this.showEditPopover.bind(this, scaleItem) }),
          h("textarea", { value: (_a = scaleItem.fillAnswer) === null || _a === void 0 ? void 0 : _a.fillContent, wrap: "soft", rows: 1, class: "inputtext", placeholder: "", style: { width: '62%', height: "26px", paddingLeft: '10px', overflow: 'auto', background: 'none' } }),
          (!this.isPreviewQuestion && !this.previewVisible) && (h("div", { class: "spanRight", style: { clear: "none", marginRight: "20px", display: "flex", justifyContent: "flex-end" } },
            h("ul", { class: "stuff" },
              h("li", { onClick: this.handleDeleteScaleItem.bind(this, scaleItem) },
                h("a", null,
                  h("i", { style: { color: "#FF9600" }, class: "comIcon vam" }, "\uE647"),
                  h("span", { class: "vam" }, "\u5220\u9664"))),
              h("div", { style: { clear: "both" } }))))),
        scaleItem.isShowEditOption && (h("div", { class: "item-edit-box" },
          h("div", { class: "item-edit-triangle" }),
          h("div", { class: "item-edit-content" },
            h("div", { class: "item-edit-input" },
              h("p", null, "\u6807\u9898\u5185\u5BB9\uFF1A"),
              h("textarea", { onInput: this.handleTitleChange.bind(this, scaleItem), value: scaleItem.questionName, wrap: "soft", rows: 1, class: "inputtext", placeholder: "", style: { width: '62%', height: "26px", paddingLeft: '10px', overflow: 'auto', background: 'none' } })),
            h("div", { class: "item-edit-option" },
              h("input", { onInput: this.handleOuterValue.bind(this, scaleItem, 'isRequired', true), checked: scaleItem.isRequired == 1, type: "checkbox", tabindex: -1, title: "\u7528\u6237\u5728\u586B\u5199\u95EE\u5377\u65F6\u5FC5\u987B\u56DE\u7B54\u8FD9\u9053\u98981" }),
              h("label", null, "\u5FC5\u7B54")),
            h("input", { onClick: this.showEditPopover.bind(this, scaleItem), type: "button", value: "\u5B8C\u6210\u7F16\u8F91", class: "submitbutton", style: { width: '100%' } }))))));
    };
    this.handleOuterValue = (scaleItem, optionType, isCheck = false, event) => {
      const inputValue = isCheck ? (event.target.checked ? 1 : 0) : event.target.value;
      console.log(event, event.target.checked, inputValue, 'inputValue', optionType);
      if (scaleItem.groupId) {
        this.questionItemList = this.questionItemList.map((item) => (item.orderbyId === scaleItem.groupId ? Object.assign(Object.assign({}, item), { scaleQuestionVOList: item.scaleQuestionVOList.map((groupItem) => (groupItem.orderbyId === scaleItem.orderbyId ? Object.assign(Object.assign({}, groupItem), { isRequired: inputValue }) : groupItem)) }) : item));
      }
      else {
        this.questionItemList = this.questionItemList.map((item) => (item.orderbyId === scaleItem.orderbyId ? Object.assign(Object.assign({}, item), { isRequired: inputValue }) : item));
      }
    };
    this.handleOptionValue = (scaleItem, radioIndex, optionType, dtoListName, isCheck = false, event) => {
      const inputValue = isCheck ? (event.target.checked ? 1 : 0) : event.target.value;
      console.log(event, event.target.checked, inputValue, 'inputValue', optionType);
      if (scaleItem.groupId) {
        this.questionItemList = this.questionItemList.map((item) => (item.orderbyId === scaleItem.groupId ? Object.assign(Object.assign({}, item), { scaleQuestionVOList: item.scaleQuestionVOList.map((groupItem) => (groupItem.orderbyId === scaleItem.orderbyId ? Object.assign(Object.assign({}, groupItem), { [dtoListName]: groupItem[dtoListName].map((radioDto, i) => (Object.assign(Object.assign({}, radioDto), { [optionType]: radioIndex === i ? inputValue : radioDto[optionType] }))) }) : groupItem)) }) : item));
      }
      else {
        this.questionItemList = this.questionItemList.map((item) => (item.orderbyId === scaleItem.orderbyId ? Object.assign(Object.assign({}, item), { [dtoListName]: scaleItem[dtoListName].map((radioDto, i) => (Object.assign(Object.assign({}, radioDto), { [optionType]: radioIndex === i ? inputValue : radioDto[optionType] }))) }) : item));
      }
    };
    this.handleInsertDto = (scaleItem, radioIndex, dtoListName) => {
      // const inputValue = (event.target as HTMLInputElement).value;
      if (scaleItem.groupId) {
        this.questionItemList = this.questionItemList.map((item) => (item.orderbyId === scaleItem.groupId ? Object.assign(Object.assign({}, item), { scaleQuestionVOList: item.scaleQuestionVOList.map((groupItem) => (groupItem.orderbyId === scaleItem.orderbyId ? Object.assign(Object.assign({}, groupItem), { [dtoListName]: [
              ...groupItem[dtoListName].slice(0, radioIndex + 1),
              {
                "isFilled": 0,
                isScore: 0,
                "optionContent": null,
                "optionName": "选项",
                "optionScore": "10",
                "ruleScore": 0,
                "ruleType": 1
              },
              ...groupItem[dtoListName].slice(radioIndex + 1, groupItem[dtoListName].length),
            ] }) : groupItem)) }) : item));
      }
      else {
        this.questionItemList = this.questionItemList.map((item) => (item.orderbyId === scaleItem.orderbyId ? Object.assign(Object.assign({}, item), { [dtoListName]: [
            ...scaleItem[dtoListName].slice(0, radioIndex + 1),
            {
              "isFilled": 0,
              isScore: 0,
              "optionContent": null,
              "optionName": "选项",
              "optionScore": "10",
              "ruleScore": 0,
              "ruleType": 1
            },
            ...scaleItem[dtoListName].slice(radioIndex + 1, scaleItem[dtoListName].length),
          ] }) : item));
      }
    };
    this.handleMinusDto = (scaleItem, radioIndex, dtoListName) => {
      console.log(scaleItem, 'scaleItem');
      // const inputValue = (event.target as HTMLInputElement).value;
      if (scaleItem.groupId) {
        this.questionItemList = this.questionItemList.map((item) => (item.orderbyId === scaleItem.groupId ? Object.assign(Object.assign({}, item), { scaleQuestionVOList: item.scaleQuestionVOList.map((groupItem) => (groupItem.orderbyId === scaleItem.orderbyId ? Object.assign(Object.assign({}, groupItem), { [dtoListName]: groupItem[dtoListName].filter((_dto, i) => radioIndex !== i) }) : groupItem)) }) : item));
      }
      else {
        this.questionItemList = this.questionItemList.map((item) => (item.orderbyId === scaleItem.orderbyId ? Object.assign(Object.assign({}, item), { [dtoListName]: scaleItem[dtoListName].filter((_dto, i) => radioIndex !== i) }) : item));
      }
    };
    this.singleRadioH5 = (scaleItem, scaleItemIndex) => {
      const paraghLength = this.getScaleIndexByFilterParagh(scaleItemIndex);
      return (h("div", { class: "right-preview-item", "data-id": scaleItem.orderbyId, key: scaleItem.orderbyId },
        h("div", { style: { position: 'relative' } },
          h("div", { class: "item-preview" },
            scaleItem.isRequired == 1 && h("span", { class: "req" }, "*"),
            h("span", null, `${scaleItemIndex + 1 - paraghLength}.${scaleItem.questionName}`)),
          h("div", { class: "item-preview-mask", onClick: this.showEditPopover.bind(this, scaleItem) }),
          h("div", { class: "ui-controlgroup column1" }, scaleItem.questionRadioList.map((radioDto) => {
            var _a;
            return (h("div", { class: "ui-radio" },
              h("span", { class: "jqradiowrapper" },
                h("input", { type: "radio", value: "1", id: "q1_1", name: "q1", style: { display: 'none' } }),
                h("a", { class: `jqradio ${((_a = scaleItem === null || scaleItem === void 0 ? void 0 : scaleItem.radioAnswer) === null || _a === void 0 ? void 0 : _a.optionId) === radioDto.id ? 'jqchecked' : ''}`, href: "javascript:;" })),
              h("div", { class: "label", style: { borderBottom: "none" } }, radioDto.optionName),
              h("div", { class: "ui-text", style: { position: 'relative', marginBottom: '10px', display: radioDto.isFilled ? 'block' : 'none' } },
                h("input", { type: "text", id: "tqq1_1", class: "OtherRadioText" }))));
          })))));
    };
    this.showScoreModal = (scaleItem, i) => {
      console.log(scaleItem, 'scaleItem');
      if (scaleItem.questionRadioList[i].isFilled == 0)
        return alert('请勾选允许填空');
      this.editScaleItem = Object.assign(Object.assign({}, scaleItem), { dtoIndex: i });
      this.isVisible = true;
    };
    // nps量表
    this.npsData = (scaleItem, scaleItemIndex) => {
      const paraghLength = this.getScaleIndexByFilterParagh(scaleItemIndex);
      console.log(scaleItem, 'npsDatanpsDatanpsData-------');
      const first = scaleItem.questionNpsList[0];
      const last = scaleItem.questionNpsList[scaleItem.questionNpsList.length - 1];
      console.log(first, last, '----------');
      return (h("div", { class: "right-preview-item", "data-id": scaleItem.orderbyId, key: scaleItem.orderbyId },
        h("div", { style: { position: 'relative' } },
          h("div", { class: "item-preview" },
            scaleItem.isRequired == 1 && h("span", { class: "req" }, "*"),
            h("span", null, `${scaleItemIndex + 1 - paraghLength}.${scaleItem.questionName}`)),
          h("div", { class: "item-preview-mask", onClick: this.showEditPopover.bind(this, scaleItem) }),
          h("div", { class: "div_table_radio_question" },
            h("ul", null,
              h("li", { class: "notchoice", style: { paddingRight: "15px", paddingTop: "5px" } },
                h("b", null, first.optionName)),
              h("li", null,
                h("ul", { class: "onscore" }, scaleItem.questionNpsList.map((npsDto, npsIndex) => (h("li", { style: { width: "30px" }, class: `${scaleItem.questionNpsList.findIndex((nps) => { var _a; return nps.id === ((_a = scaleItem === null || scaleItem === void 0 ? void 0 : scaleItem.npsAnswer) === null || _a === void 0 ? void 0 : _a.npsId); }) >= npsIndex ? 'on6' : 'off6'}` }, npsDto.optionScore))))),
              h("li", { class: "notchoice", style: { paddingLeft: "15px", paddingTop: "5px" } },
                h("b", null, last.optionName)),
              h("div", { style: { clear: "both" } }))),
          (!this.isPreviewQuestion && !this.previewVisible) && (h("div", { class: "spanRight", style: { clear: "none", marginRight: "20px", display: "flex", justifyContent: "flex-end" } },
            h("ul", { class: "stuff" },
              h("li", { onClick: this.handleDeleteScaleItem.bind(this, scaleItem) },
                h("a", null,
                  h("i", { style: { color: "#FF9600" }, class: "comIcon vam" }, "\uE647"),
                  h("span", { class: "vam" }, "\u5220\u9664"))),
              h("div", { style: { clear: "both" } }))))),
        scaleItem.isShowEditOption && (h("div", { class: "item-edit-box" },
          h("div", { class: "item-edit-triangle" }),
          h("div", { class: "item-edit-content" },
            h("div", { class: "item-edit-input" },
              h("p", null, "\u6807\u9898\u5185\u5BB9\uFF1A"),
              h("textarea", { onInput: this.handleTitleChange.bind(this, scaleItem), value: scaleItem.questionName, wrap: "soft", rows: 1, class: "inputtext", placeholder: "", style: { width: '62%', height: "26px", paddingLeft: '10px', overflow: 'auto', background: 'none' } })),
            h("div", { class: "container", style: { position: "relative" } },
              h("div", { style: { paddingTop: "10px" } }),
              h("div", { style: { clear: "both", width: "100%" } },
                h("div", { class: "selScrrol", style: { textAlign: "center" } },
                  h("div", { class: "choise_bg" }),
                  h("table", { class: "tableoption", cellspacing: "0", cellpadding: "0" },
                    h("tbody", null,
                      h("tr", { style: { backgroundColor: '#FAFAFA' } },
                        h("td", { style: { width: "340px", padding: "3px 5px" } },
                          h("span", null,
                            h("a", { title: "\u4EA4\u6362\u9009\u9879\u6587\u5B57", href: "javascript:;", style: { color: "rgb(34, 34, 34)", marginLeft: "7px", textDecoration: "none" } }, "\u9009\u9879\u6587\u5B57"))),
                        h("td", { style: { width: "110px", padding: "3px 5px" } },
                          h("span", null,
                            h("input", { type: "checkbox", tabindex: "-1", title: "\u7ED9\u9009\u9879\u8BBE\u7F6E\u5206\u6570\uFF0C\u53EF\u7528\u4E8ELikert\u91CF\u8868\u6216\u8005\u6D4B\u8BD5\u7C7B\u578B\u7684\u95EE\u5377", disabled: true, style: { display: "none" } }),
                            h("span", { style: { cursor: "pointer" } }, "\u00A0\u5206\u6570")))),
                      scaleItem.questionNpsList.map((npsDto, npsIndex) => (h("tr", { style: { backgroundColor: '#FAFAFA' } },
                        h("td", { style: { width: "340px" } },
                          h("input", { onInput: this.handleOptionValue.bind(this, scaleItem, npsIndex, 'optionName', 'questionNpsList', false), value: npsDto.optionName, type: "text", class: "choicetxt choicetxt", tabindex: "1", title: "\u56DE\u8F66\u6DFB\u52A0\u65B0\u9009\u9879\uFF0C\u4E0A\u4E0B\u952E\u7F16\u8F91\u524D\u540E\u9009\u9879", style: { width: "255px", border: "1px solid rgb(205, 205, 205)" } }),
                          h("span", { onClick: this.handleInsertDto.bind(this, scaleItem, npsIndex, 'questionNpsList'), title: "\u5728\u6B64\u9009\u9879\u4E0B\u9762\u63D2\u5165\u4E00\u4E2A\u65B0\u7684\u9009\u9879", class: "choiceimg design-icon design-add", style: { cursor: "pointer", marginLeft: "3px" } }),
                          h("span", { onClick: this.handleMinusDto.bind(this, scaleItem, npsIndex, 'questionNpsList'), title: "\u5220\u9664\u5F53\u524D\u9009\u9879\uFF08\u6700\u5C11\u4FDD\u75592\u4E2A\u9009\u9879\uFF09", class: "choiceimg design-icon design-minus" })),
                        h("td", null,
                          h("span", null,
                            h("input", { onInput: this.handleOptionValue.bind(this, scaleItem, npsIndex, 'optionScore', 'questionNpsList', false), value: npsDto.optionScore, type: "text", class: "choicetxt", maxlength: "5", title: "\u5728\u6B64\u53EF\u4EE5\u8BBE\u7F6E\u6BCF\u4E2A\u9009\u9879\u7684\u5206\u6570\uFF08\u8BF7\u8F93\u5165\u6574\u6570\uFF09", style: { width: "30px" } })),
                          h("span", { class: "wjx__templet__beautifyInput" }, "\u00A0")))))))))),
            h("div", { class: "item-edit-option" },
              h("input", { onInput: this.handleOuterValue.bind(this, scaleItem, 'isRequired', true), checked: scaleItem.isRequired == 1, type: "checkbox", tabindex: -1, title: "\u7528\u6237\u5728\u586B\u5199\u95EE\u5377\u65F6\u5FC5\u987B\u56DE\u7B54\u8FD9\u9053\u9898" }),
              h("label", null, "\u5FC5\u7B54")),
            h("input", { onClick: this.showEditPopover.bind(this, scaleItem), type: "button", value: "\u5B8C\u6210\u7F16\u8F91", class: "submitbutton", style: { width: '100%' } }))))));
    };
    // nps量表
    this.npsDataH5 = (scaleItem, scaleItemIndex) => {
      const paraghLength = this.getScaleIndexByFilterParagh(scaleItemIndex);
      return (h("div", { class: "right-preview-item", "data-id": scaleItem.orderbyId, key: scaleItem.orderbyId },
        h("div", { style: { position: 'relative' } },
          h("div", { class: "item-preview" },
            scaleItem.isRequired == 1 && h("span", { class: "req" }, "*"),
            h("span", null, `${scaleItemIndex + 1 - paraghLength}.${scaleItem.questionName}`)),
          h("div", { class: "item-preview-mask", onClick: this.showEditPopover.bind(this, scaleItem) }),
          h("div", { class: "div_table_radio_question" },
            h("ul", { style: { display: 'flex', flexDirection: 'column' } },
              h("div", { class: "row-between" }),
              h("li", null,
                h("ul", { class: "onscore" }, scaleItem.questionNpsList.map((npsDto, npsIndex) => (h("li", { style: { width: "30px" }, class: `${scaleItem.questionNpsList.findIndex((nps) => { var _a; return nps.id === ((_a = scaleItem === null || scaleItem === void 0 ? void 0 : scaleItem.npsAnswer) === null || _a === void 0 ? void 0 : _a.npsId); }) >= npsIndex ? 'on6' : 'off6'}` }, npsDto.optionName))))))))));
    };
    this.handleTableInput = (scaleItem, tableType, tableList, event) => {
      const inputValue = event.target.value;
      console.log(event, inputValue.split('\n'), 'inputValue', scaleItem);
      if (scaleItem.groupId) {
        this.questionItemList = this.questionItemList.map((item) => (item.orderbyId === scaleItem.groupId ? Object.assign(Object.assign({}, item), { scaleQuestionVOList: item.scaleQuestionVOList.map((groupItem) => (groupItem.orderbyId === scaleItem.orderbyId ? Object.assign(Object.assign({}, groupItem), { [tableList]: inputValue.split('\n').map((value) => ({ [tableType]: value })) }) : groupItem)) }) : item));
        this.questionItemList = this.questionItemList.map((item) => (item.orderbyId === scaleItem.groupId ? Object.assign(Object.assign({}, item), { scaleQuestionVOList: item.scaleQuestionVOList.map((groupItem) => (groupItem.orderbyId === scaleItem.orderbyId ? Object.assign(Object.assign({}, groupItem), { questionTableList: groupItem.rowList.reduce((prev, cur, i, _arr) => {
              let tableList = [];
              groupItem.colList.forEach((col, colIndex) => {
                // console.log(groupItem, 'groupItem', prev, i, colIndex)
                tableList.push(Object.assign(Object.assign(Object.assign({}, cur), col), { value: i * (groupItem.colList.length) + colIndex + 1 }));
              });
              console.log(tableList, 'tableList');
              return prev.concat(tableList);
            }, []) }) : groupItem)) }) : item));
      }
      else {
        this.questionItemList = this.questionItemList.map((item) => (item.orderbyId === scaleItem.orderbyId ? Object.assign(Object.assign({}, item), { [tableList]: inputValue.split('\n').map((value) => ({ [tableType]: value })) }) : item));
        this.questionItemList = this.questionItemList.map((item) => (item.orderbyId === scaleItem.orderbyId ? Object.assign(Object.assign({}, item), { questionTableList: item.rowList.reduce((prev, cur, i, _arr) => {
            let tableList = [];
            item.colList.forEach((col, colIndex) => {
              console.log(item, 'item', prev, i, colIndex);
              tableList.push(Object.assign(Object.assign(Object.assign({}, cur), col), { value: i * (item.colList.length) + colIndex + 1 }));
            });
            console.log(tableList, 'tableList');
            return prev.concat(tableList);
          }, []) }) : item));
      }
      console.log(this.questionItemList, 'this.questionItemList');
    };
    // 矩阵填空
    this.tableInput = (scaleItem, scaleItemIndex) => {
      const paraghLength = this.getScaleIndexByFilterParagh(scaleItemIndex);
      // rowList -- 行标题
      console.log('--');
      console.log(scaleItem.colList, scaleItem.rowList, 'rowList');
      const colNameList = scaleItem.colList.map((tableDto) => (tableDto.colName)); // 获取列标题
      const rowNameList = scaleItem.rowList.map((tableDto) => (tableDto.rowName)); // 获取行标题
      const colNameListString = scaleItem.colList.map((tableDto) => (tableDto.colName)).join('\n');
      const rowNameListString = scaleItem.rowList.map((tableDto) => (tableDto.rowName)).join('\n');
      return (h("div", { class: "right-preview-item", "data-id": scaleItem.orderbyId, key: scaleItem.orderbyId },
        h("div", { style: { position: 'relative' } },
          h("div", { class: "item-preview" },
            scaleItem.isRequired == 1 && h("span", { class: "req" }, "*"),
            h("span", null, `${scaleItemIndex + 1 - paraghLength}.${scaleItem.questionName}`)),
          h("div", { class: "item-preview-mask", onClick: this.showEditPopover.bind(this, scaleItem) }),
          h("table", { style: { width: "100%" }, cellpadding: "5", cellspacing: "0" },
            h("thead", null,
              h("tr", null,
                h("th", null),
                colNameList.map((tableDto) => (h("td", null, tableDto))))),
            h("tbody", null, rowNameList.map((tableDto, i) => (h("tr", null,
              h("th", { style: { borderBottom: i === rowNameList.length - 1 ? '' : "1px solid #efefef" } }, tableDto),
              scaleItem.questionTableList[0].questionColDataList ?
                scaleItem.questionTableList[i].questionColDataList.map((col) => (h("td", { style: { borderBottom: i === rowNameList.length - 1 ? '' : "1px solid #efefef" } },
                  h("textarea", { value: col.colValue, disabled: true, class: "inputtext", style: { overflow: "hidden", height: "22px", width: "100px" } })))) :
                scaleItem.colList.map((col) => (h("td", { style: { borderBottom: i === rowNameList.length - 1 ? '' : "1px solid #efefef" } },
                  h("textarea", { value: col.colValue, disabled: true, class: "inputtext", style: { overflow: "hidden", height: "22px", width: "100px" } })))),
              h("th", { style: { borderBottom: i === rowNameList.length - 1 ? '' : "1px solid #efefef" } })))))),
          (!this.isPreviewQuestion && !this.previewVisible) && (h("div", { class: "spanRight", style: { clear: "none", marginRight: "20px", display: "flex", justifyContent: "flex-end" } },
            h("ul", { class: "stuff" },
              h("li", { onClick: this.handleDeleteScaleItem.bind(this, scaleItem) },
                h("a", null,
                  h("i", { style: { color: "#FF9600" }, class: "comIcon vam" }, "\uE647"),
                  h("span", { class: "vam" }, "\u5220\u9664"))),
              h("div", { style: { clear: "both" } }))))),
        scaleItem.isShowEditOption && (h("div", { class: "item-edit-box" },
          h("div", { class: "item-edit-triangle" }),
          h("div", { class: "item-edit-content" },
            h("div", { class: "item-edit-input" },
              h("p", null, "\u6807\u9898\u5185\u5BB9\uFF1A"),
              h("textarea", { onInput: this.handleTitleChange.bind(this, scaleItem), value: scaleItem.questionName, wrap: "soft", rows: 1, class: "inputtext", placeholder: "", style: { width: '62%', height: "26px", paddingLeft: '10px', overflow: 'auto', background: 'none' } })),
            h("div", { style: { clear: "both", width: "500px" } },
              h("div", { class: "spanLeft", style: { position: "relative", zIndex: "1", width: "505px", padding: '10px 0' } },
                h("div", { class: "matrixtitle", style: { width: "246px" } },
                  h("div", { class: "matrixhead", style: { paddingLeft: "4px" } },
                    h("span", { style: { float: "left" } },
                      h("b", null,
                        "\u884C\u6807\u9898",
                        h("span", { class: "fullScreen", style: { display: "inline-block", verticalAlign: "middle", marginLeft: "3px" }, title: "\u653E\u5927\u6587\u672C\u6846\u8FDB\u884C\u7F16\u8F91" }))),
                    h("div", { class: "divclear" })),
                  h("textarea", { onInput: this.handleTableInput.bind(this, scaleItem, 'rowName', 'rowList'), value: rowNameListString, wrap: "off", rows: 7, class: "inputtext", tabindex: "1", title: "\u76F8\u5F53\u4E8E\u6BCF\u4E2A\u5C0F\u9898\u7684\u6807\u9898", style: { width: "220px", height: "154px", overflow: "auto", padding: "2px", marginTop: "7px" } })),
                h("div", { class: "spanLeft", style: { width: "229px" } },
                  h("div", { class: "matrixhead" },
                    h("b", null, "\u5217\u6807\u9898"),
                    "\u00A0"),
                  h("textarea", { onInput: this.handleTableInput.bind(this, scaleItem, 'colName', 'colList'), value: colNameListString, wrap: "soft", rows: 7, class: "inputtext", title: "\u5217\u6807\u9898", style: { width: "220px", height: "154px", overflow: "auto", margin: "7px 0px 0px 4px", padding: "2px" } })),
                h("div", { class: "divclear" }),
                h("div", { style: { clear: "both" } }))),
            h("div", { class: "item-edit-option" },
              h("input", { onInput: this.handleOuterValue.bind(this, scaleItem, 'isRequired', true), checked: scaleItem.isRequired == 1, type: "checkbox", tabindex: -1, title: "\u7528\u6237\u5728\u586B\u5199\u95EE\u5377\u65F6\u5FC5\u987B\u56DE\u7B54\u8FD9\u9053\u9898" }),
              h("label", null, "\u5FC5\u7B54")),
            h("input", { onClick: this.showEditPopover.bind(this, scaleItem), type: "button", value: "\u5B8C\u6210\u7F16\u8F91", class: "submitbutton", style: { width: '100%' } }))))));
    };
    this.tableInputH5 = (scaleItem, scaleItemIndex) => {
      // const colNameList = scaleItem.colList.map((tableDto: any) => (tableDto.colName))
      const rowNameList = scaleItem.rowList.map((tableDto) => (tableDto.rowName));
      return (h("div", { class: "right-preview-item", "data-id": scaleItem.orderbyId, key: scaleItem.orderbyId },
        h("div", { style: { position: 'relative' } },
          h("div", { class: "item-preview" },
            scaleItem.isRequired == 1 && h("span", { class: "req" }, "*"),
            h("span", null, `${scaleItemIndex + 1}.${scaleItem.questionName}`)),
          h("div", { class: "item-preview-mask", onClick: this.showEditPopover.bind(this, scaleItem) }),
          rowNameList.map((col) => (h("div", null,
            h("div", { class: "select_title", id: "drv4_1t" }, col),
            h("div", { id: "drv4_1", class: "mdivtable" },
              h("table", { class: "matrix-rating" },
                h("tbody", null, scaleItem.colList.map((row) => (h(Fragment, null,
                  h("tr", null,
                    h("td", { class: "title" }, row.colName)),
                  h("tr", null,
                    h("td", null,
                      h("div", { class: "ui-input-text" },
                        h("input", { value: row.colValue, type: "text", id: "q4_0_0", name: "q4_0_0" }))))))))),
              h("div", { class: "errorMessage" }))))))));
    };
    this.paragraph = (scaleItem, _scaleItemIndex) => {
      return (h("div", { class: "right-preview-item", "data-id": scaleItem.orderbyId, key: scaleItem.orderbyId },
        h("div", { style: { position: 'relative' } },
          h("div", { class: "item-preview-mask", onClick: this.showEditPopover.bind(this, scaleItem) }),
          h("textarea", { value: scaleItem.questionName, wrap: "soft", rows: 1, class: "inputtext", placeholder: "\u8BF7\u8F93\u5165\u6BB5\u843D\u8BF4\u660E", style: { width: '62%', height: "26px", paddingLeft: '10px', overflow: 'auto', background: 'none', border: 'unset' } }),
          (!this.isPreviewQuestion && !this.previewVisible) && (h("div", { class: "spanRight", style: { clear: "none", marginRight: "20px", display: "flex", justifyContent: "flex-end" } },
            h("ul", { class: "stuff" },
              h("li", { onClick: this.handleDeleteScaleItem.bind(this, scaleItem) },
                h("a", null,
                  h("i", { style: { color: "#FF9600" }, class: "comIcon vam" }, "\uE647"),
                  h("span", { class: "vam" }, "\u5220\u9664"))),
              h("div", { style: { clear: "both" } }))))),
        scaleItem.isShowEditOption && (h("div", { class: "item-edit-box" },
          h("div", { class: "item-edit-triangle" }),
          h("div", { class: "item-edit-content" },
            h("div", { class: "item-edit-input", style: { marginBottom: '10px' } },
              h("p", null, "\u6BB5\u843D\u8BF4\u660E\uFF1A"),
              h("textarea", { onInput: this.handleTitleChange.bind(this, scaleItem), value: scaleItem.questionName, wrap: "soft", rows: 1, class: "inputtext", placeholder: "", style: { width: '62%', height: "26px", paddingLeft: '10px', overflow: 'auto', background: 'none' } })),
            h("input", { onClick: this.showEditPopover.bind(this, scaleItem), type: "button", value: "\u5B8C\u6210\u7F16\u8F91", class: "submitbutton", style: { width: '100%' } }))))));
    };
    this.completeEdit = (scaleItem) => {
      this.questionItemList = this.questionItemList.map((item) => (Object.assign(Object.assign({}, item), { isEditGroup: scaleItem.orderbyId === item.orderbyId ? !item.isEditGroup : false })));
    };
    // 标题修改
    this.handleGroupTitleChange = (scaleItem, event) => {
      const inputValue = event.target.value;
      console.log(scaleItem, event, inputValue);
      this.questionItemList = this.questionItemList.map((item) => (item.orderbyId === scaleItem.orderbyId ? Object.assign(Object.assign({}, item), { questionName: inputValue }) : item));
    };
    this.questionGroup = (scaleItem, scaleItemIndex) => {
      const paraghLength = this.getScaleIndexByFilterParagh(scaleItemIndex);
      return (h("div", { class: "right-preview-item", "data-id": scaleItem.orderbyId, key: scaleItem.orderbyId },
        h("div", { style: { position: 'relative' } },
          (!this.isPreviewQuestion && !this.previewVisible) && h("div", { class: "right-preview-isEdit", onClick: this.completeEdit.bind(this, scaleItem) }, scaleItem.isEditGroup ? '完成' : '编辑'),
          h("div", { class: "item-preview-mask", style: { bottom: "0", zIndex: "-100" }, onClick: this.showEditPopover.bind(this, scaleItem) }),
          scaleItem.isRequired == 1 && h("span", { class: "req" }, "*"),
          h("span", { style: { position: 'relative', top: '-3px' } },
            `${scaleItemIndex + 1 - paraghLength}`,
            "."),
          h("textarea", { onInput: this.handleGroupTitleChange.bind(this, scaleItem), value: scaleItem.questionName, wrap: "soft", rows: 1, class: "inputtext", placeholder: "\u8BF7\u8F93\u5165\u95EE\u9898\u7EC4\u6807\u9898", style: { width: '62%', height: "26px", paddingLeft: '10px', overflow: 'auto', background: 'none', marginBottom: '10px' } }),
          (!this.isPreviewQuestion && !this.previewVisible) && (h("div", { class: "spanRight", style: { clear: "none", marginRight: "20px", display: "flex", justifyContent: "flex-end" } },
            h("ul", { class: "stuff" },
              h("li", { onClick: this.handleDeleteScaleItem.bind(this, scaleItem) },
                h("a", null,
                  h("i", { style: { color: "#FF9600" }, class: "comIcon vam" }, "\uE647"),
                  h("span", { class: "vam" }, "\u5220\u9664"))),
              h("div", { style: { clear: "both" } }))))),
        scaleItem.scaleQuestionVOList.map((questionVO, i) => {
          // 单项填空
          if (questionVO.questionType == 1) {
            return (this.singleInput(questionVO, i));
          }
          // 评分单选
          if (questionVO.questionType == 2) {
            return (this.singleRadio(questionVO, i));
          }
          // nps量表
          if (questionVO.questionType == 3) {
            return (this.npsData(questionVO, i));
          }
          // 表格填空矩阵
          if (questionVO.questionType == 4) {
            return (this.tableInput(questionVO, i));
          }
          // 段落说明
          if (questionVO.questionType == 5) {
            return (this.paragraph(questionVO, i));
          }
        })));
    };
    this.questionGroupH5 = (scaleItem, scaleItemIndex) => {
      const paraghLength = this.getScaleIndexByFilterParagh(scaleItemIndex);
      return (h("div", { class: "right-preview-item", "data-id": scaleItem.orderbyId, key: scaleItem.orderbyId },
        h("div", { style: { position: 'relative' } },
          (!this.isPreviewQuestion && !this.previewVisible) && h("div", { class: "right-preview-isEdit", onClick: this.completeEdit.bind(this, scaleItem) }, scaleItem.isEditGroup ? '完成' : '编辑'),
          h("div", { class: "item-preview-mask", style: { bottom: "0", zIndex: "-100" }, onClick: this.showEditPopover.bind(this, scaleItem) }),
          scaleItem.isRequired == 1 && h("span", { class: "req" }, "*"),
          h("span", { style: { position: 'relative', top: '-3px' } },
            `${scaleItemIndex + 1 - paraghLength}`,
            "."),
          h("textarea", { value: scaleItem.questionName, wrap: "soft", rows: 1, class: "inputtext", placeholder: "\u8BF7\u8F93\u5165\u95EE\u9898\u7EC4\u6807\u9898", style: { width: '62%', height: "26px", paddingLeft: '10px', overflow: 'auto', background: 'none', marginBottom: '10px' } }),
          (!this.isPreviewQuestion && !this.previewVisible) && (h("div", { class: "spanRight", style: { clear: "none", marginRight: "20px", display: "flex", justifyContent: "flex-end" } },
            h("ul", { class: "stuff" },
              h("li", { onClick: this.handleDeleteScaleItem.bind(this, scaleItem) },
                h("a", null,
                  h("i", { style: { color: "#FF9600" }, class: "comIcon vam" }, "\uE647"),
                  h("span", { class: "vam" }, "\u5220\u9664"))),
              h("div", { style: { clear: "both" } }))))),
        scaleItem.scaleQuestionVOList.map((questionVO, i) => {
          // 单项填空
          if (questionVO.questionType == 1) {
            return (this.singleInput(questionVO, i));
          }
          // 评分单选
          if (questionVO.questionType == 2) {
            return (this.singleRadioH5(questionVO, i));
          }
          // nps量表
          if (questionVO.questionType == 3) {
            return (this.npsDataH5(questionVO, i));
          }
          // 表格填空矩阵
          if (questionVO.questionType == 4) {
            return (this.tableInputH5(questionVO, i));
          }
          // 段落说明
          if (questionVO.questionType == 5) {
            return (this.paragraph(questionVO, i));
          }
        })));
    };
    // 返回量表题目
    this.renderQuestionItemByType = () => {
      var _a;
      console.log(this.questionItemList, 'this.questionItemList');
      return ((_a = this.questionItemList) === null || _a === void 0 ? void 0 : _a.map((scaleItem, i) => {
        // 单项填空
        if (scaleItem.questionType == 1) {
          return (this.singleInput(scaleItem, i));
        }
        // 评分单选
        if (scaleItem.questionType == 2) {
          return (this.singleRadio(scaleItem, i));
        }
        // nps量表
        if (scaleItem.questionType == 3) {
          return (this.npsData(scaleItem, i));
        }
        // 表格填空矩阵
        if (scaleItem.questionType == 4) {
          return (this.tableInput(scaleItem, i));
        }
        // 段落说明
        if (scaleItem.questionType == 5) {
          return (this.paragraph(scaleItem, i));
        }
        // 问题组
        if (scaleItem.questionType == 6) {
          return (this.questionGroup(scaleItem, i));
        }
      }));
    };
    this.renderH5QuestionItemByType = () => {
      var _a;
      return ((_a = this.questionItemList) === null || _a === void 0 ? void 0 : _a.map((scaleItem, i) => {
        // 单项填空
        if (scaleItem.questionType == 1) {
          return (this.singleInput(scaleItem, i));
        }
        // 评分单选
        if (scaleItem.questionType == 2) {
          return (this.singleRadioH5(scaleItem, i));
        }
        // nps量表
        if (scaleItem.questionType == 3) {
          return (this.npsDataH5(scaleItem, i));
        }
        // 表格填空矩阵
        if (scaleItem.questionType == 4) {
          return (this.tableInputH5(scaleItem, i));
        }
        // 段落说明
        if (scaleItem.questionType == 5) {
          return (this.paragraph(scaleItem, i));
        }
        // 问题组
        if (scaleItem.questionType == 6) {
          return (this.questionGroupH5(scaleItem, i));
        }
      }));
    };
  }
  scaleInfoHandler(newValue, oldValue) {
    console.log('The new value of activated is: ', newValue, 'Old val: ', oldValue);
    this.scaleName = newValue.scaleName;
    this.scaleDesc = newValue.scaleDesc;
    this.questionItemList = newValue.scaleQuestionList || [];
    this.resultScore = newValue.resultScore;
  }
  isPreviewQuestionHandler(newValue) {
    console.log('The new value of activated is: ', newValue, 'Old val: ');
    this.isPreviewQuestion = newValue;
  }
  scaleQuestionChangeHandler() {
    // console.log(todo, 'todo')
    if (!this.scaleName)
      return alert('请填写模板名称');
    if (!this.scaleDesc)
      return alert('请填写模板描述');
    if (this.questionItemList.length === 0)
      return alert('请至少添加一个问题');
    // const filterTableQuestion = this.questionItemList
    //   .filter((item: any) => item.questionType === '4')
    //   .every((item) => )
    this.questionItemList = this.questionItemList.map((item, i) => (Object.assign(Object.assign({}, item), { orderbyId: i + 1 })));
    this.scaleQuestionChange.emit({
      scaleName: this.scaleName,
      scaleDesc: this.scaleDesc,
      questionItemList: this.questionItemList
    });
  }
  visibleChangeHandler() {
    this.visibleChange.emit(false);
  }
  pageBackHandler() {
    // console.log(todo, 'todo')
    this.pageBack.emit();
  }
  // 初始化
  componentWillLoad() {
    console.log('componentWillLoad', this.scaleInfo);
    this.scaleInfoHandler(this.scaleInfo, {});
  }
  componentDidRender() {
    console.log('componentDidRender', this.scaleInfo);
    // this.scaleName = this.scaleInfo.scaleName;
    // this.scaleDesc = this.scaleInfo.scaleName;
    // this.questionItemList = this.scaleInfo.scaleQuestionList;
    //第二组
    var g2 = this.g2;
    var ops2 = {
      animation: 1000,
      draggable: ".right-preview-item",
      group: { name: "itxst.com", pull: true, put: true },
      //拖动结束
      onEnd: (evt) => {
        console.log(evt);
        //获取拖动后的排序
        var arr = sortable2.toArray();
        this.sortArr = arr;
        this.questionItemList = arr.reduce((prev, cur, _i, _arr) => {
          return prev.concat(this.questionItemList.filter((item) => item.orderbyId == cur));
        }, []);
        console.log(this.questionItemList, ' this.questionItemList');
        console.log(arr, 'arr');
        // this.msg.innerHTML ="B组排序结果："+ JSON.stringify(arr);
      },
    };
    var sortable2 = Sortable.create(g2, ops2);
  }
  singleRadio(scaleItem, scaleItemIndex) {
    var _a;
    const paraghLength = this.getScaleIndexByFilterParagh(scaleItemIndex);
    const optionContent = ((_a = scaleItem === null || scaleItem === void 0 ? void 0 : scaleItem.radioAnswer) === null || _a === void 0 ? void 0 : _a.optionContent) || 0;
    return (h("div", { class: "right-preview-item", "data-id": scaleItem.orderbyId, key: scaleItem.orderbyId },
      h("div", { style: { position: 'relative' } },
        h("div", { class: "item-preview" },
          scaleItem.isRequired == 1 && h("span", { class: "req" }, "*"),
          h("span", null, `${scaleItemIndex + 1 - paraghLength}.${scaleItem.questionName}`)),
        h("div", { class: "item-preview-mask", onClick: this.showEditPopover.bind(this, scaleItem) }),
        h("ul", null,
          scaleItem.questionRadioList.map((radioDto) => {
            var _a, _b;
            return (h("li", { style: { minHeight: "32px", width: "99%", display: 'flex' } },
              h("a", { href: "###", class: `jqRadio ${((radioDto === null || radioDto === void 0 ? void 0 : radioDto.id) && ((_a = scaleItem === null || scaleItem === void 0 ? void 0 : scaleItem.radioAnswer) === null || _a === void 0 ? void 0 : _a.optionId) === (radioDto === null || radioDto === void 0 ? void 0 : radioDto.id)) ? 'jqChecked' : ''}`, style: { position: "static" } }),
              h("input", { style: { display: "none" }, type: "radio" }),
              h("label", { style: { verticalAlign: "middle", paddingLeft: "2px" } }, radioDto.optionName + '这里是选项'),
              radioDto.isFilled ? (h("div", null,
                h("input", { type: "text", class: "underline", style: { color: '#999999', maxWidth: '500px', textAlign: 'center' }, readonly: true, value: (_b = scaleItem === null || scaleItem === void 0 ? void 0 : scaleItem.radioAnswer) === null || _b === void 0 ? void 0 : _b.optionContent }),
                h("span", { style: { color: "#efa030", fontSize: "14px" } },
                  "\u00A0(\u5206\u503C\uFF1A",
                  radioDto.ruleType === 1 ? radioDto.ruleScore * optionContent : optionContent ? optionContent / radioDto.ruleScore : 0,
                  ")"))) : (h("span", { style: { color: "#efa030", fontSize: "14px" } },
                "\u00A0(\u5206\u503C\uFF1A",
                radioDto.optionScore,
                ")"))));
          }),
          h("div", { style: { clear: "both" } })),
        (!this.isPreviewQuestion && !this.previewVisible) && (h("div", { class: "spanRight", style: { clear: "none", marginRight: "20px", display: "flex", justifyContent: "flex-end" } },
          h("ul", { class: "stuff" },
            h("li", { onClick: this.handleDeleteScaleItem.bind(this, scaleItem) },
              h("a", null,
                h("i", { style: { color: "#FF9600" }, class: "comIcon vam" }, "\uE647"),
                h("span", { class: "vam" }, "\u5220\u9664"))),
            h("div", { style: { clear: "both" } }))))),
      scaleItem.isShowEditOption && (h("div", { class: "item-edit-box" },
        h("div", { class: "item-edit-triangle" }),
        h("div", { class: "item-edit-content" },
          h("div", { class: "item-edit-input" },
            h("p", null, "\u6807\u9898\u5185\u5BB9\uFF1A"),
            h("textarea", { onInput: this.handleTitleChange.bind(this, scaleItem), value: scaleItem.questionName, wrap: "soft", rows: 1, class: "inputtext", placeholder: "", style: { width: '62%', height: "26px", paddingLeft: '10px', overflow: 'auto', background: 'none' } })),
          h("div", { class: "container", style: { position: "relative" } },
            h("div", { style: { paddingTop: "10px" } }),
            h("div", { style: { clear: "both", width: "100%" } },
              h("div", { class: "selScrrol", style: { textAlign: "center" } },
                h("div", { class: "choise_bg" }),
                h("table", { class: "tableoption", cellspacing: "0", cellpadding: "0" },
                  h("tbody", null,
                    h("tr", { style: { backgroundColor: '#FAFAFA' } },
                      h("td", { style: { width: "300px", padding: "3px 5px" } },
                        h("span", null,
                          h("a", { title: "\u4EA4\u6362\u9009\u9879\u6587\u5B57", href: "javascript:;", style: { color: "rgb(34, 34, 34)", marginLeft: "7px", textDecoration: "none" } }, "\u9009\u9879\u6587\u5B57"))),
                      h("td", { style: { letterSpacing: "1px", width: "200px", padding: "3px 5px", textAlign: 'center' } },
                        h("span", null, "\u5141\u8BB8\u586B\u7A7A")),
                      h("td", { style: { width: "200px", padding: "3px 5px", textAlign: 'center' } },
                        h("span", null,
                          h("input", { type: "checkbox", tabindex: "-1", title: "\u7ED9\u9009\u9879\u8BBE\u7F6E\u5206\u6570\uFF0C\u53EF\u7528\u4E8ELikert\u91CF\u8868\u6216\u8005\u6D4B\u8BD5\u7C7B\u578B\u7684\u95EE\u5377", style: { display: "none" } }),
                          h("span", { style: { cursor: "pointer" } }, "\u00A0\u5206\u503C"))),
                      h("td", { style: { display: "block", padding: "3px 5px" } })),
                    scaleItem.questionRadioList.map((radioDto, radioIndex) => (h("tr", { style: { background: '#FAFAFA' } },
                      h("td", { style: { width: "280px" } },
                        h("input", { onInput: this.handleOptionValue.bind(this, scaleItem, radioIndex, 'optionName', 'questionRadioList', false), value: radioDto.optionName, type: "text", class: "choicetxt choicetxt", tabindex: "1", title: "\u56DE\u8F66\u6DFB\u52A0\u65B0\u9009\u9879\uFF0C\u4E0A\u4E0B\u952E\u7F16\u8F91\u524D\u540E\u9009\u9879", style: { width: "205px", border: "1px solid rgb(205, 205, 205)" } }),
                        h("span", { onClick: this.handleInsertDto.bind(this, scaleItem, radioIndex, 'questionRadioList'), title: "\u5728\u6B64\u9009\u9879\u4E0B\u9762\u63D2\u5165\u4E00\u4E2A\u65B0\u7684\u9009\u9879", class: "choiceimg design-icon design-add", style: { cursor: "pointer", marginLeft: "3px" } }),
                        h("span", { onClick: this.handleMinusDto.bind(this, scaleItem, radioIndex, 'questionRadioList'), title: "\u5220\u9664\u5F53\u524D\u9009\u9879\uFF08\u6700\u5C11\u4FDD\u75592\u4E2A\u9009\u9879\uFF09", class: "choiceimg design-icon design-minus" })),
                      h("td", null,
                        h("div", { class: "flexdq" },
                          h("span", { class: "wjx__templet__beautifyInput" },
                            h("input", { onInput: this.handleOptionValue.bind(this, scaleItem, radioIndex, 'isFilled', 'questionRadioList', true), checked: radioDto.isFilled, type: "checkbox", tabindex: "-1", id: "cbmt2_1_6454539033", class: "checkbox" })))),
                      h("td", { style: { textAlign: 'center' } },
                        h("span", null,
                          h("input", { disabled: radioDto.isFilled, onInput: this.handleOptionValue.bind(this, scaleItem, radioIndex, 'optionScore', 'questionRadioList', false), value: radioDto.optionScore, type: "text", class: "choicetxt", maxlength: "5", title: "\u5728\u6B64\u53EF\u4EE5\u8BBE\u7F6E\u6BCF\u4E2A\u9009\u9879\u7684\u5206\u6570\uFF08\u8BF7\u8F93\u5165\u6574\u6570\uFF09", style: { width: "30px" } }))),
                      h("td", { onClick: this.showScoreModal.bind(this, scaleItem, radioIndex), style: { color: "#bbb", textDecoration: "underline", cursor: 'pointer', textAlign: 'center' } }, "\u5206\u503C\u8BA1\u7B97\u516C\u5F0F")))))))),
            h("div", { class: "divclear" })),
          h("div", { class: "item-edit-option" },
            h("input", { onInput: this.handleOuterValue.bind(this, scaleItem, 'isRequired', true), checked: scaleItem.isRequired == 1, type: "checkbox", tabindex: -1, title: "\u7528\u6237\u5728\u586B\u5199\u95EE\u5377\u65F6\u5FC5\u987B\u56DE\u7B54\u8FD9\u9053\u9898" }),
            h("label", null, "\u5FC5\u7B54")),
          h("input", { onClick: this.showEditPopover.bind(this, scaleItem), type: "button", value: "\u5B8C\u6210\u7F16\u8F91", class: "submitbutton", style: { width: '100%' } }))))));
  }
  render() {
    var _a, _b, _c;
    console.log('BLUB', this.scaleInfo);
    // this.scaleName = this.scaleInfo.scaleName;
    // this.scaleDesc = this.scaleInfo.scaleName;
    // this.questionItemList = this.scaleInfo.scaleQuestionList;
    const leftNavList = [
      {
        type: 'title',
        label: '填空题'
      },
      {
        type: 'item',
        label: '单项填空'
      },
      {
        type: 'title',
        label: '评分题'
      },
      {
        type: 'item',
        label: '评分单选'
      },
      {
        type: 'item',
        label: 'NPS量表'
      },
      {
        type: 'title',
        label: '矩阵题'
      },
      {
        type: 'item',
        label: '表格填空'
      },
      {
        type: 'title',
        label: '辅助布局'
      },
      {
        type: 'item',
        label: '问题组'
      },
      {
        type: 'item',
        label: '段落说明'
      },
    ];
    return (h("div", { style: { position: 'relative' } },
      !this.isOnlyPreview && (h(Fragment, null,
        !this.isPreviewQuestion && (h("div", { id: "ss-header" },
          h("div", { class: "divMenu-container", style: { left: "0" } },
            h("div", { class: "newBtn preview", onClick: () => this.pageBackHandler() },
              h("span", null, "\u8FD4\u56DE"))),
          h("div", { class: "divMenu-container" },
            h("div", { class: "newBtn preview", onClick: () => {
                this.hideAllPopover();
                this.previewVisible = true;
              } },
              h("span", null, "\u9884\u89C8")),
            h("div", { onClick: () => this.scaleQuestionChangeHandler(), class: "newBtn overEdit", id: "hrefFiQ" },
              h("span", null, "\u5B8C\u6210\u7F16\u8F91"))))),
        h("div", { class: "box", style: { display: 'flex', justifyContent: 'center', height: 'calc(100vh - 204px)' } },
          !this.isPreviewQuestion && (h("div", { id: "topnav", class: "overflowBarStyle" },
            h("div", { id: "g1", ref: (el) => this.g1 = el }, leftNavList.map((item) => (h("div", { onClick: this.handleLeftBarClick.bind(this, item), class: item.type === 'title' ? "left-bar-title" : "left-bar-item" }, item.label)))))),
          h("div", { class: "survey editContainBox", id: "sur" },
            h("div", { id: "g2", ref: (el) => this.g2 = el, class: "itxst" },
              h("div", { class: "template-header" },
                h("div", { class: "template-header-name" },
                  h("p", null, "\u6A21\u677F\u540D\u79F0\uFF1A"),
                  h("textarea", { disabled: this.isPreviewQuestion, onInput: this.handleValue.bind(this, 'scaleName'), value: this.scaleName, wrap: "soft", rows: 1, class: "inputtext", placeholder: "", style: { width: '62%', height: "26px", paddingLeft: '10px', overflow: 'auto', background: 'none' } })),
                h("div", { class: "template-header-desc" },
                  h("p", null, "\u6A21\u677F\u8BF4\u660E\uFF1A"),
                  h("textarea", { disabled: this.isPreviewQuestion, onInput: this.handleValue.bind(this, 'scaleDesc'), value: this.scaleDesc, wrap: "soft", rows: 3, class: "inputtext", placeholder: "", style: { width: '62%', height: "90px", padding: '10px', overflow: 'auto', background: 'none' } }))),
              this.renderQuestionItemByType()))))),
      h("my-modal", { isVisible: this.isVisible, modaltitle: "\u6DFB\u52A0\u5206\u503C\u8BA1\u7B97\u516C\u5F0F", width: "400px", onValueChange: (ev) => {
          console.log(ev.detail, 'ev');
          this.isVisible = ev.detail;
        }, onSureCommit: () => {
          this.isVisible = false;
          console.log('onSureCommit');
        } },
        h("div", { class: "row-center", style: { minHeight: '100px' } },
          h("p", null, "\u5206\u503C = \u586B\u7A7A\u5185\u5BB9\u00A0"),
          h("select", { onInput: this.handleOptionValue.bind(this, this.editScaleItem, this.editScaleItem.dtoIndex, 'ruleType', 'questionRadioList', false) },
            h("option", { value: "1" }, "*"),
            h("option", { value: "2" }, "/")),
          h("textarea", { value: (_c = (_a = this.editScaleItem) === null || _a === void 0 ? void 0 : _a.questionRadioList[(_b = this.editScaleItem) === null || _b === void 0 ? void 0 : _b.dtoIndex]) === null || _c === void 0 ? void 0 : _c.ruleScore, onInput: this.handleOptionValue.bind(this, this.editScaleItem, this.editScaleItem.dtoIndex, 'ruleScore', 'questionRadioList', false), wrap: "soft", rows: 1, class: "inputtext", placeholder: "", style: { width: '60px', height: "26px", paddingLeft: '10px', marginLeft: '8px', overflow: 'auto', background: 'none' } }))),
      h("my-modal", { isVisible: this.previewVisible, modaltitle: this.isOnlyComputer ? "查看结果" : "预览", width: "1040px", hideOption: true, onValueChange: (ev) => {
          console.log(ev.detail, 'ev');
          if (this.isOnlyPreview) {
            this.visibleChangeHandler();
          }
          else {
            this.previewVisible = ev.detail;
          }
        }, onSureCommit: () => {
          this.previewVisible = false;
          console.log('onSureCommit');
        } },
        !this.isOnlyComputer && (h("div", { class: "question-toggle-btn" },
          h("input", { type: "button", onClick: () => this.isPC = false, style: { marginLeft: '8px' }, class: `wjxui-btn ${this.isPC ? 'wjxui-btn-primary' : ''}`, value: "\u624B\u673A\u9884\u89C8" }),
          h("input", { type: "button", onClick: () => this.isPC = true, style: { marginLeft: '8px' }, class: `wjxui-btn ${!this.isPC ? 'wjxui-btn-primary' : ''}`, value: "\u7535\u8111\u9884\u89C8" }))),
        h("div", { class: this.isPC ? '' : 'h5container' },
          h("div", { class: "template-header" },
            h("div", { class: "template-header-name" },
              h("p", null, "\u6A21\u677F\u540D\u79F0\uFF1A"),
              h("textarea", { disabled: this.previewVisible, onInput: this.handleValue.bind(this, 'scaleName'), value: this.scaleName, wrap: "soft", rows: 1, class: "inputtext", placeholder: "", style: { width: '62%', height: "26px", paddingLeft: '10px', overflow: 'auto', background: 'none' } })),
            h("div", { class: "template-header-desc" },
              h("p", null, "\u6A21\u677F\u8BF4\u660E\uFF1A"),
              h("textarea", { disabled: this.previewVisible, onInput: this.handleValue.bind(this, 'scaleDesc'), value: this.scaleDesc, wrap: "soft", rows: 3, class: "inputtext", placeholder: "", style: { width: '62%', height: "90px", padding: '10px', overflow: 'auto', background: 'none' } }))),
          this.isPC ? this.renderQuestionItemByType() : this.renderH5QuestionItemByType(),
          this.resultScore != '' && this.resultScore != 0 && h("div", { class: 'resultScore' },
            "\u603B\u5206\uFF1A",
            this.resultScore)))));
  }
  static get is() { return "my-component"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["my-component.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["my-component.css"]
  }; }
  static get properties() { return {
    "previewVisible": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "preview-visible",
      "reflect": false,
      "defaultValue": "false"
    },
    "isOnlyComputer": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "is-only-computer",
      "reflect": false,
      "defaultValue": "false"
    },
    "scaleInfo": {
      "type": "unknown",
      "mutable": true,
      "complexType": {
        "original": "{\r\n    scaleName: '',\r\n    scaleDesc: '',\r\n    scaleQuestionList: []\r\n  }",
        "resolved": "{ scaleName: \"\"; scaleDesc: \"\"; scaleQuestionList: []; }",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "defaultValue": "null"
    },
    "isPreviewQuestion": {
      "type": "boolean",
      "mutable": true,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "is-preview-question",
      "reflect": true,
      "defaultValue": "false"
    },
    "isOnlyPreview": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "is-only-preview",
      "reflect": false,
      "defaultValue": "false"
    }
  }; }
  static get states() { return {
    "scaleName": {},
    "scaleDesc": {},
    "questionItemList": {},
    "resultScore": {},
    "isPC": {},
    "sortArr": {},
    "editScaleItem": {},
    "isVisible": {}
  }; }
  static get events() { return [{
      "method": "scaleQuestionChange",
      "name": "scaleQuestionChange",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      }
    }, {
      "method": "visibleChange",
      "name": "visibleChange",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      }
    }, {
      "method": "pageBack",
      "name": "pageBack",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      }
    }]; }
  static get watchers() { return [{
      "propName": "scaleInfo",
      "methodName": "scaleInfoHandler"
    }, {
      "propName": "isPreviewQuestion",
      "methodName": "isPreviewQuestionHandler"
    }]; }
}
